@@ -1,5 +1,5 @@
-/* GNU Solfege - eartraining for GNOME
- * Copyright (C) 2000, 2001  Tom Cato Amundsen
+/* GNU Solfege - ear training for GNOME
+ * Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 /*#define be_verbose 1*/
-#include <config.h>
+#include "../config.h"
 #include <sys/soundcard.h>
 #include <fcntl.h>
 #include <unistd.h>
