@@ -130,8 +130,8 @@ class Question(dict):
         if "C-name" in self:
             return self["C-name"]
         return "[no name]"
-    def get_music(self):
-        return self['m_lessonfile'].prepare_music_from_string(self, 'music')
+    def get_music(self, varname='music'):
+        return self['m_lessonfile'].prepare_music_from_string(self, varname)
 
 class DataparserException(Exception):
     def __init__(self, filename, lexer):
@@ -161,7 +161,7 @@ class NameLookupException(DataparserException):
         return ret
 
 
-class SyntaxError(DataparserException):
+class DataparserSyntaxError(DataparserException):
     def __init__(self, parser, msg=""):
         DataparserException.__init__(self, parser.m_filename,
                                       parser._lexer)
@@ -245,7 +245,7 @@ class Lexer:
             self.pos += 1
             return self.m_tokens[self.pos-1][1]
         else:
-            raise SyntaxError(self.m_parser, "Token '%s' not found, found '%s' of type %s " %(t, self.m_tokens[self.pos][1], self.m_tokens[self.pos][0]))
+            raise DataparserSyntaxError(self.m_parser, "Token '%s' not found, found '%s' of type %s " %(t, self.m_tokens[self.pos][1], self.m_tokens[self.pos][0]))
     def get_line(self, lineno):
         """line 0 is the first line
         Return an empty string if lineno is out of range.
@@ -299,7 +299,7 @@ class Dataparser:
                 and self._lexer.peek_type(1) == '(':
             self.include()
         else:
-            raise SyntaxError(self, "Expected token '=' or '{', found  '%s' of type %s" % (self._lexer.peek_string(), self._lexer.peek_type() ))
+            raise DataparserSyntaxError(self, "Expected token '=' or '{', found  '%s' of type %s" % (self._lexer.peek_string(), self._lexer.peek_type() ))
     def include(self):
         self._lexer.scan_any() # scan include
         self._lexer.scan_any() # scan (
@@ -330,7 +330,7 @@ class Dataparser:
         """NAME "=" faktor ("," faktor)* """
         name = self._lexer.scan_any()#('NAME')
         if name in self.reserved_words:
-            raise SyntaxError(self, "Assignment to reserved word '%s'" % name)
+            raise DataparserSyntaxError(self, "Assignment to reserved word '%s'" % name)
         self._lexer.scan_any()#('=')
         faktorlist = self.faktorlist()
         if len(faktorlist) == 1:
@@ -386,7 +386,7 @@ class Dataparser:
                 return self.functioncall()
             return self.lookup_name(self._lexer.scan('NAME'))
         else:
-            raise SyntaxError(self, "Expected STRING, INTEGER or NAME+'(', found '%s' of type %s" % (self._lexer.peek_type(), self._lexer.peek_type()))
+            raise DataparserSyntaxError(self, "Expected STRING, INTEGER or NAME+'(', found '%s' of type %s" % (self._lexer.peek_type(), self._lexer.peek_type()))
     def functioncall(self):
         """functioncall: NAME "(" faktorlist ")" """
         name = self._lexer.scan_any()#'NAME')
@@ -403,7 +403,7 @@ class Dataparser:
             arglist = self.faktorlist()
             self._lexer.scan(')')
             try:
-                return apply(self.functions[name], arglist)
+                return self.functions[name](*arglist)
             except KeyError:
                 raise NameLookupException(name, self)
     def block(self):
@@ -415,7 +415,7 @@ class Dataparser:
             self.questions.append(Question())
             self.context = self.questions[-1]
         else:
-            raise SyntaxError(self,  "Unknown block name '%s'" % name)
+            raise DataparserSyntaxError(self,  "Unknown block name '%s'" % name)
         self._lexer.scan_any() # scan '{'
         # The question block is a little more code because of the shortcut
         # we allow: question { "music string }
