@@ -126,6 +126,8 @@ class HTMLWriter(formatter.NullWriter):
         self.g_tw.add_child_at_anchor(self.g_table_table, a)
         self.m_tableidx = [0, 0]
     def end_td(self):
+        """called when a cell (TD or TH) is ended.
+        """
         hbox = gtk.HBox()
         hbox.show()
         self.g_table_table.attach(hbox, self.m_tableidx[0], self.m_tableidx[0]+1, self.m_tableidx[1], self.m_tableidx[1]+1)
@@ -328,6 +330,14 @@ class MyHTMLParser(htmllib.HTMLParser):
     def end_td(self, *v):
         self.m_writer.m_tableidx[0] += 1
         self.m_writer.end_td()
+    def start_th(self, *x):
+        """Must exist to make the parser call end_th"""
+        self.m_writer.new_font(("20", None, 1, None))
+        pass
+    def end_th(self, *x):
+        self.m_writer.m_tableidx[0] += 1
+        self.m_writer.end_td()
+        self.m_writer.new_font(None)
 
 class TextViewHtmlWidget(gtk.ScrolledWindow, _HtmlWidgetCommon):
     def __init__(self, activate_cb, anchor_track_cb):
@@ -621,16 +631,18 @@ def _test():
     import gtk
     class TestWin(gtk.Window):
         def __init__(self):
+            global s
             gtk.Window.__init__(self)
             self.set_size_request(700, 400)
             self.g_html1 = TextViewHtmlWidget(self.activate_cb, self.anchor_track_cb)
             self.g_html2 = GtkHtml2Widget(self.activate_cb, self.anchor_track_cb)
-            self.m_filename = sys.argv[-1:][0]
-            print "filename", self.m_filename
-            if sys.argv[-1:][0].endswith('.html'):
-                s = file(sys.argv[-1:][0]).read()
-                self.g_html1.source(s)
-                self.g_html2.source(s)
+            if len(sys.argv) > 1:
+                self.m_filename = sys.argv[-1:][0]
+                print "filename", self.m_filename
+                if sys.argv[-1:][0].endswith('.html'):
+                   s = file(sys.argv[-1:][0]).read()
+            self.g_html1.source(s)
+            self.g_html2.source(s)
             vbox = gtk.VBox()
             self.add(vbox)
             button = gtk.Button("Reload")
