@@ -17,9 +17,9 @@
 
 __exercise_data__ = {
     'exercise_name': 'id-by-name',
-    'menu_path': '%s/%s' % (_("_Misc exercises"), _("Id_entify by name")),
     'stock-icon': 'solfege-id-by-name',
-    'toolbar': 5,
+    'menupath': '/Menubar/FileMenu/MiscMenu',
+    'name': _("Id_entify by name"),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
@@ -130,7 +130,7 @@ class Gui(abstract.LessonbasedGui):
         self.add_random_transpose_gui()
         # -----------------------------------------
         self.g_select_questions_category_box, category_box= gu.hig_category_vbox(
-            _("Select questions to ask"))
+            _("Questions to ask"))
         self.config_box.pack_start(self.g_select_questions_category_box, True)
         self.g_select_questions = widgets.QuestionNameCheckButtonTable(self.m_t)
         self.g_select_questions.initialize(4, 0)
