@@ -79,7 +79,7 @@ window_actions = [
     ('NewLessonfile', gtk.STOCK_NEW, None, None, 'new file', 'file_new_cb'),
     ('Open', gtk.STOCK_OPEN, None, None, 'Open lesson file', 'file_open_cb'),
     ('Save', gtk.STOCK_SAVE, None, None, 'Save the lesson file', 'file_save_cb'),
-    ('SaveAs', gtk.STOCK_SAVE_AS, None, None, 'Save the lesson file with a new name', 'file_save_as_cb'),
+    ('SaveAs', gtk.STOCK_SAVE_AS, None, '<shift><ctrl>s', 'Save the lesson file with a new name', 'file_save_as_cb'),
     ('Quit', gtk.STOCK_QUIT, None, None, 'Quit program', 'quit_cb'),
     ('HelpMenu', None, _('_Help')),
     ('HelpHelp', gtk.STOCK_HELP, None, None, None, 'help_cb'),
@@ -97,19 +97,19 @@ lessonfile_actions = [
     ('NewQuestion', gtk.STOCK_ADD, None, None,
      _('Add a new question'), 'new_question_cb'),
     ('NoteheadCursor', 'solfege-notehead', None, None,
-     _('Select tool to add noteheads'), 'select_cursor_notehead_cb'),
+     _('Add noteheads'), 'select_cursor_notehead_cb'),
     ('SharpCursor', 'solfege-sharp', None, None,
-     _('Select tool to add sharps to tones'), 'select_cursor_sharp_cb'),
+     _('Add sharps'), 'select_cursor_sharp_cb'),
     ('DoubleSharpCursor', 'solfege-double-sharp', None, None,
-     _('Select tool to add double-sharps to tones'), 'select_cursor_2sharp_cb'),
+     _('Add double-sharps'), 'select_cursor_2sharp_cb'),
     ('NaturalCursor', 'solfege-natural', None, None,
-     _('Select tool to remove any accidental from tones'), 'select_cursor_natural_cb'),
+     _('Remove accidentals'), 'select_cursor_natural_cb'),
     ('FlatCursor', 'solfege-flat', None, None,
-     _('Select tool to add flats to tones'), 'select_cursor_flat_cb'),
+     _('Add flats'), 'select_cursor_flat_cb'),
     ('DoubleFlatCursor', 'solfege-double-flat', None, None,
-     _('Select tool to add double-flats to tones'), 'select_cursor_2flat_cb'),
+     _('Add double-flats'), 'select_cursor_2flat_cb'),
     ('EraseCursor', 'solfege-erase', None, None,
-     _('Select tool to erase tones'), 'select_cursor_erase_cb'),
+     _('Erase tones'), 'select_cursor_erase_cb'),
 ]
 ui_string = """<ui>
   <menubar name='Menubar'>
@@ -278,19 +278,11 @@ class MainWin(gtk.Window):
                 break
         self.update_appwin()
     def file_open_cb(self, *v):
-        if gtk_api == "2.0":
-            dialog = gtk.FileSelection()
-        else:
-            dialog = gtk.FileChooserDialog(_("Open.."), self,
-                                       gtk.FILE_CHOOSER_ACTION_OPEN,
-                                       (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                                        gtk.STOCK_OPEN, gtk.RESPONSE_OK))
-            dialog.set_default_response(gtk.RESPONSE_OK)
-            filter = gtk.FileFilter()
-            filter.set_name(_("All files"))
-            filter.add_pattern("*")
-            dialog.add_filter(filter)
-        dialog.hide()
+        dialog = gtk.FileChooserDialog(_("Open..."), self,
+                                   gtk.FILE_CHOOSER_ACTION_OPEN,
+                                   (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+                                    gtk.STOCK_OPEN, gtk.RESPONSE_OK))
+        dialog.set_default_response(gtk.RESPONSE_OK)
         if dialog.run() == gtk.RESPONSE_OK:
             filename = dialog.get_filename()
             try:
@@ -312,19 +304,11 @@ class MainWin(gtk.Window):
             self.update_appwin()
     def file_save_as_cb(self, *v):
         self.store_data_from_ui()
-        if gtk_api == "2.0":
-            dialog = gtk.FileSelection()
-        else:
-            dialog = gtk.FileChooserDialog(_("Save as..."), self,
-                                      gtk.FILE_CHOOSER_ACTION_SAVE,
-                                       (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                                        gtk.STOCK_SAVE, gtk.RESPONSE_OK))
-            dialog.set_default_response(gtk.RESPONSE_OK)
-            filter = gtk.FileFilter()
-            filter.set_name(_("All files"))
-            filter.add_pattern("*")
-            dialog.add_filter(filter)
-        dialog.hide()
+        dialog = gtk.FileChooserDialog(_("Save as..."), self,
+                                  gtk.FILE_CHOOSER_ACTION_SAVE,
+                                   (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+                                    gtk.STOCK_SAVE, gtk.RESPONSE_OK))
+        dialog.set_default_response(gtk.RESPONSE_OK)
 
         if dialog.run() == gtk.RESPONSE_OK:
             self.m_P.m_filename = dialog.get_filename()
@@ -333,19 +317,11 @@ class MainWin(gtk.Window):
     def file_save_cb(self, *v):
         self.store_data_from_ui()
         if self.m_P.m_filename is None:
-            if gtk_api == "2.0":
-                dialog = gtk.FileSelection()
-            else:
-                dialog = gtk.FileChooserDialog(_("Save..."), self,
-                                       gtk.FILE_CHOOSER_ACTION_SAVE,
-                                       (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                                        gtk.STOCK_SAVE, gtk.RESPONSE_OK))
-                dialog.set_default_response(gtk.RESPONSE_OK)
-                filter = gtk.FileFilter()
-                filter.set_name(_("All files"))
-                filter.add_pattern("*")
-                dialog.add_filter(filter)
-            dialog.hide()
+            dialog = gtk.FileChooserDialog(_("Save..."), self,
+                                   gtk.FILE_CHOOSER_ACTION_SAVE,
+                                   (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+                                    gtk.STOCK_SAVE, gtk.RESPONSE_OK))
+            dialog.set_default_response(gtk.RESPONSE_OK)
 
             if dialog.run() == gtk.RESPONSE_OK:
                 self.m_P.m_filename = dialog.get_filename()
@@ -507,20 +483,8 @@ class UIManagerMainWin(MainWin):
         self.toplevel_vbox.pack_start(self.ui.get_widget('/Toolbar'), False)
 
 def main(datadir):
-    global gtk_api
     mpd.engravers.fetadir = os.path.join(datadir, "feta")
-    if gtk.pygtk_version < (2, 2, 96):
-        gtk_api = "2.0"
-    else:
-        gtk_api = "2.4"
-    if len(sys.argv) > 1 and sys.argv[1] == '--old':
-        gtk_api = "2.0"
-        del sys.argv[1]
-
-    if gtk_api == "2.0":
-        w = ItemFactoryMainWin(datadir)
-    else:
-        w = UIManagerMainWin(datadir)
+    w = UIManagerMainWin(datadir)
     if len(sys.argv) == 2:
         w.load_file(sys.argv[1])
     w.show()
