@@ -31,11 +31,6 @@ if sys.version_info < (2, 3):
     print "********************************************************************"
     sys.exit(-1)
 
-# i18n should be imported very early in program init because it setup
-# the _ and _i functions for the whole program.
-import i18n
-i18n.setup()
-
 import configureoutput
 
 import optparse
@@ -259,9 +254,9 @@ class MusicViewerWindow(gtk.Dialog):
         self.g_music_displayer.display(music, fontsize)
 
 class MainWin(gnome.ui.App, cfg.ConfigUtils):
-    def __init__(self, options):
+    def __init__(self, options, datadir):
         gnome.ui.App.__init__(self, 'solfege', 'GNU Solfege')
-        self.icons = stock.SolfegeIconFactory(self, configureoutput.datadir)
+        self.icons = stock.SolfegeIconFactory(self, datadir)
         self.set_default_size(400, 400)
         pixbuf = self.render_icon('solfege-icon', gtk.ICON_SIZE_DIALOG)
         self.set_icon(pixbuf)
@@ -575,10 +570,13 @@ cfg.set_bool('config/no_random', bool(options.no_random))
 if splash_win:
     splash_win.show_progress("creating MainWin")
 
-w = MainWin(options)
-w.show()
 if splash_win:
     splash_win.destroy()
-w.post_constructor()
-gtk.main()
+
+def start_app(prefix, datadir):
+    w = MainWin(options, datadir)
+    w.show()
+    w.post_constructor()
+    import gtk
+    gtk.main()
 
