@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,14 +17,14 @@
 
 __exercise_data__ = {
     'exercise_name': 'rhythm',
-    'menu_path': '%s/%s' % (_("_Rhythm"), _("Rh_ythm")),
-    'icon': 'graphics/rhythm24.png',
-    'toolbar': 11,
+    'stock-icon': 'solfege-rhythm',
+    'menupath': '/Menubar/FileMenu/RhythmMenu',
+    'name': _("Rh_ythm"),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
-import gtk, gnome.ui
+import gtk, gnome.ui, gobject
 import abstract, const, gu, mpd, soundcard
 import random, os
 import cfg
@@ -54,12 +54,12 @@ class Teacher(abstract.Teacher):
                Teacher.ERR_NO_ELEMS : if no elements are set to be practised.
         """
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
                  and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
-             return Teacher.ERR_PICKY
+            return Teacher.ERR_PICKY
 
         self.q_status = const.QSTATUS_NO
 
@@ -100,7 +100,7 @@ class Teacher(abstract.Teacher):
         assert self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]
         v = []
         for idx in range(len(self.m_question)):
-           v.append(self.m_question[idx] == a[idx])
+            v.append(self.m_question[idx] == a[idx])
         if filter(lambda a: a == 0, v) == []:
             self.q_status = const.QSTATUS_SOLVED
             self.maybe_auto_new_question()
@@ -124,10 +124,9 @@ def create_rhythm_image(rhythm):
     rhythm : a string like 'c8 c8' or 'c8 c16 c16'
     The image returned is shown.
     """
-    fn = 'rhythm-%s' % ''.join(rhythm.split())
     im = gtk.Image()
-    im.set_from_file(os.path.join('graphics', fn)+'.png')
-    #im.set_from_pixbuf(im.get_pixbuf().scale_simple(24, 24, gtk.gdk.INTERP_BILINEAR))
+    im.set_from_stock('solfege-rhythm-%s' % ''.join(rhythm.split()),
+                      gtk.ICON_SIZE_LARGE_TOOLBAR)
     im.show()
     return im
 
@@ -157,7 +156,7 @@ class RhythmViewer(gtk.Frame):
         create those |__| that represents one beat
         """
         if self.__timeout:
-            gtk.timeout_remove(self.__timeout)
+            gobject.source_remove(self.__timeout)
         self.clear()
         for x in range(self.m_num_beats):
             self.g_box.pack_start(create_png_image('holder'), False)
@@ -178,12 +177,6 @@ class RhythmViewer(gtk.Frame):
         self.m_data = self.m_data[:n]
         for x in range(n, self.m_num_beats):
             self.g_box.pack_start(create_png_image('holder'), False)
-    def add_elem(self, fn):
-        #UGH remove/rename/whatever?
-        im = gtk.Image()
-        im.set_from_file('graphics/%s' % fn)
-        im.show()
-        self.g_box.pack_start(im, False)
     def add_rhythm_element(self, i):
         assert len(self.m_data) <= self.m_num_beats
         if len(self.g_box.get_children()) >= self.m_num_beats:
@@ -201,6 +194,10 @@ class RhythmViewer(gtk.Frame):
             self.g_box.pack_start(create_png_image('holder'), False)
             del self.m_data[-1]
     def mark_wrong(self, idx):
+        """
+        Mark the rhythm elements that was wrong by putting the content of
+        graphics/rhythm-wrong.png (normally a red line) under the element.
+        """
         box = gtk.VBox()
         r = self.g_box.get_children()[idx]
         self.g_box.get_children()[idx].reparent(box)
@@ -215,13 +212,19 @@ class RhythmViewer(gtk.Frame):
         self.g_face = gtk.EventBox()
         self.g_face.connect('button_press_event', self.on_sadface_event)
         self.g_face.show()
-        self.g_face.add(create_png_image('sadface-32x32'))
+        im = gtk.Image()
+        im.set_from_stock('solfege-sadface', gtk.ICON_SIZE_LARGE_TOOLBAR)
+        im.show()
+        self.g_face.add(im)
         self.g_box.pack_start(self.g_face, False)
     def happy_face(self):
         self.g_face = gtk.EventBox()
         self.g_face.connect('button_press_event', self.on_happyface_event)
         self.g_face.show()
-        self.g_face.add(create_png_image("happyface-32x32"))
+        im = gtk.Image()
+        im.set_from_stock('solfege-happyface', gtk.ICON_SIZE_LARGE_TOOLBAR)
+        im.show()
+        self.g_face.add(im)
         self.g_box.pack_start(self.g_face, False)
     def on_happyface_event(self, obj, event):
         if event.type == gtk.gdk.BUTTON_PRESS and event.button == 1:
@@ -236,7 +239,7 @@ class RhythmViewer(gtk.Frame):
         l.set_alignment(0.0, 0.5)
         l.show()
         self.g_box.pack_start(l, True, True)
-        self.__timeout = gtk.timeout_add(const.NORMAL_WAIT, self.unflash)
+        self.__timeout = gobject.timeout_add(const.NORMAL_WAIT, self.unflash)
     def unflash(self, *v):
         self.__timeout = None
         self.clear()
@@ -262,6 +265,7 @@ class Gui(abstract.Gui):
         self.practise_box.pack_start(gtk.HBox(), False,
                                      padding=gnome.ui.PAD_SMALL)
         self.g_rhythm_viewer = RhythmViewer(self)
+        #FIXME the value 52 is dependant on the theme used
         self.g_rhythm_viewer.set_size_request(-1, 52)
         self.g_rhythm_viewer.create_holders()
         self.practise_box.pack_start(self.g_rhythm_viewer, False)
@@ -308,7 +312,7 @@ class Gui(abstract.Gui):
         table.attach(gu.nSpinButton(self.m_exname, "num_beats",
                      gtk.Adjustment(4, 1, 100, 1, 10)),
                      1, 2, 0, 1, xoptions=gtk.FILL)
-        menu = gu.PercussionNameOptionMenu(self.m_exname, "rhythm_perc", "Side Stick")
+        menu = gu.PercussionNameComboBox(self.m_exname, "rhythm_perc", "Side Stick")
         table.attach(menu, 2, 3, 0, 1, xoptions=gtk.FILL)
         label = gtk.Label(_("Count in before question:"))
         label.set_alignment(1.0, 0.5)
@@ -317,7 +321,7 @@ class Gui(abstract.Gui):
         table.attach(gu.nSpinButton(self.m_exname, "count_in",
                      gtk.Adjustment(2, 0, 10, 1, 10)),
                      1, 2, 1, 2, xoptions=gtk.FILL)
-        menu = gu.PercussionNameOptionMenu(self.m_exname, "countin_perc", "Claves")
+        menu = gu.PercussionNameComboBox(self.m_exname, "countin_perc", "Claves")
         table.attach(menu, 2, 3, 1, 2, xoptions=gtk.FILL)
         #-----
         self.config_box.pack_start(gtk.HBox(), False,
@@ -350,7 +354,7 @@ class Gui(abstract.Gui):
         return btn
     def on_backspace(self, widget=None):
         if self.m_t.q_status == const.QSTATUS_SOLVED:
-           return
+            return
         self.g_rhythm_viewer.backspace()
         if not self.g_rhythm_viewer.m_data:
             self.g_backspace.set_sensitive(False)
